@@ -2,6 +2,7 @@
 
 import json
 
+
 def is_identical(fpath_1: str, fpath_2: str) -> bool:
     file_contents = []
     for i, fpath in enumerate([fpath_1, fpath_2]):
@@ -23,4 +24,10 @@ def is_identical(fpath_1: str, fpath_2: str) -> bool:
 def load_json(fpath: str) -> dict:
     with open(fpath, "r") as f:
         data = json.load(f)
-    return data
\ No newline at end of file
+    return data
+
+
+if __name__ == "__main__":
+    fpath_1 = "/media/findux/DATA/potholes/Potholes Dataset-20230123T145709Z-007b.zip"
+    fpath_2 = "/media/findux/DATA/potholes/Potholes Dataset-20230123T145709Z-007.zip"
+    print(is_identical(fpath_1, fpath_2))
\ No newline at end of file
